From 81d79a79e4b29e9314b64b2e4c49b48ae8319767 Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Tue, 11 Oct 2011 08:50:45 -0400
Subject: [PATCH] - WebDAV Users: show only domains that run on Apache (because nginx does not have full WebDAV support).

---
 interface/web/sites/ftp_user_edit.php |  142 +++++++++++++++++++++++++++++++++++++++++------
 1 files changed, 124 insertions(+), 18 deletions(-)

diff --git a/interface/web/sites/ftp_user_edit.php b/interface/web/sites/ftp_user_edit.php
index 61f549c..337fe16 100644
--- a/interface/web/sites/ftp_user_edit.php
+++ b/interface/web/sites/ftp_user_edit.php
@@ -40,12 +40,10 @@
 
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
+require_once('tools.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
@@ -58,24 +56,76 @@
 		
 		// we will check only users, not admins
 		if($_SESSION["s"]["user"]["typ"] == 'user') {
-			
-			// Get the limits of the client
-			$client_group_id = $_SESSION["s"]["user"]["default_group"];
-			$client = $app->db->queryOneRecord("SELECT limit_ftp_user FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
-			
-			// Check if the user may add another ftp user.
-			if($client["limit_ftp_user"] >= 0) {
-				$tmp = $app->db->queryOneRecord("SELECT count(ftp_user_id) as number FROM ftp_user WHERE sys_groupid = $client_group_id");
-				if($tmp["number"] >= $client["limit_ftp_user"]) {
-					$app->error($app->tform->wordbook["limit_ftp_user_txt"]);
-				}
+			if(!$app->tform->checkClientLimit('limit_ftp_user')) {
+				$app->error($app->tform->wordbook["limit_ftp_user_txt"]);
+			}
+			if(!$app->tform->checkResellerLimit('limit_ftp_user')) {
+				$app->error('Reseller: '.$app->tform->wordbook["limit_ftp_user_txt"]);
 			}
 		}
 		
 		parent::onShowNew();
 	}
+
+	function onShowEnd() {
+		global $app, $conf, $interfaceConf;
+		/*
+		 * If the names are restricted -> remove the restriction, so that the
+		 * data can be edited
+		 */
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		// $ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		$ftpuser_prefix = replacePrefix($global_config['ftpuser_prefix'], $this->dataRecord);
+		
+		if ($this->dataRecord['username'] != ""){
+			/* REMOVE the restriction */
+			$app->tpl->setVar("username", preg_replace('/'.$ftpuser_prefix.'/' , '', $this->dataRecord['username'], 1));
+		}
+		if($_SESSION["s"]["user"]["typ"] == 'admin' || $app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+			$app->tpl->setVar("username_prefix", $global_config['ftpuser_prefix']);
+		}
+		else {
+			$app->tpl->setVar("username_prefix", $ftpuser_prefix);
+		}
+
+		parent::onShowEnd();
+	}
 	
-	function onAfterInsert() {
+	function onSubmit() {
+		global $app, $conf;
+		
+		// Get the record of the parent domain
+		$parent_domain = $app->db->queryOneRecord("select * FROM web_domain WHERE domain_id = ".intval(@$this->dataRecord["parent_domain_id"]));
+		
+		// Set a few fixed values
+		$this->dataRecord["server_id"] = $parent_domain["server_id"];
+		
+		//die(print_r($this->dataRecord));
+		
+		if(isset($this->dataRecord['username']) && trim($this->dataRecord['username']) == '') $app->tform->errorMessage .= $app->tform->lng('username_error_empty').'<br />';
+		if(isset($this->dataRecord['username']) && empty($this->dataRecord['parent_domain_id'])) $app->tform->errorMessage .= $app->tform->lng('parent_domain_id_error_empty').'<br />';
+		
+		parent::onSubmit();
+	}
+	
+	function onBeforeInsert() {
+		global $app, $conf, $interfaceConf;
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		//$ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		$ftpuser_prefix = replacePrefix($global_config['ftpuser_prefix'], $this->dataRecord);
+		
+		if ($app->tform->errorMessage == '') {
+			$this->dataRecord['username'] = $ftpuser_prefix . $this->dataRecord['username'];
+		}
+		
+		parent::onBeforeInsert();
+	}
+
+		function onAfterInsert() {
 		global $app, $conf;
 		
 		$web = $app->db->queryOneRecord("SELECT * FROM web_domain WHERE domain_id = ".intval($this->dataRecord["parent_domain_id"]));
@@ -84,15 +134,71 @@
 		$uid = $web["system_user"];
 		$gid = $web["system_group"];
 		
-		$sql = "UPDATE ftp_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid' WHERE ftp_user_id = ".$this->id;
+		// The FTP user shall be owned by the same group then the website
+		$sys_groupid = $web['sys_groupid'];
+		
+		$sql = "UPDATE ftp_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid', sys_groupid = '$sys_groupid' WHERE ftp_user_id = ".$this->id;
 		$app->db->query($sql);
 		
+		
+	}
+
+	function onBeforeUpdate() {
+		global $app, $conf, $interfaceConf;
+
+		/*
+		 * If the names should be restricted -> do it!
+		 */
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		//$ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		$ftpuser_prefix = replacePrefix($global_config['ftpuser_prefix'], $this->dataRecord);
+		
+		/* restrict the names */
+		if ($app->tform->errorMessage == '') {
+			$this->dataRecord['username'] = $ftpuser_prefix . $this->dataRecord['username'];
+		}
 	}
 	
 	function onAfterUpdate() {
 		global $app, $conf;
 		
+		//* When the site of the FTP user has been changed
+		if($this->oldDataRecord['parent_domain_id'] != $this->dataRecord['parent_domain_id']) {
+			$web = $app->db->queryOneRecord("SELECT * FROM web_domain WHERE domain_id = ".intval($this->dataRecord["parent_domain_id"]));
+			$server_id = $web["server_id"];
+			$dir = $web["document_root"];
+			$uid = $web["system_user"];
+			$gid = $web["system_group"];
 		
+			// The FTP user shall be owned by the same group then the website
+			$sys_groupid = $web['sys_groupid'];
+		
+			$sql = "UPDATE ftp_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid', sys_groupid = '$sys_groupid' WHERE ftp_user_id = ".$this->id;
+			$app->db->query($sql);
+		}
+		
+	}
+	
+	function getClientName() {
+		global $app, $conf;
+	
+		if($_SESSION["s"]["user"]["typ"] != 'admin' && !$app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+			// Get the group-id of the user
+			$client_group_id = $_SESSION["s"]["user"]["default_group"];
+		} else {
+			// Get the group-id from the data itself
+			$web = $app->db->queryOneRecord("SELECT sys_groupid FROM web_domain WHERE domain_id = ".intval($this->dataRecord['parent_domain_id']));
+			$client_group_id = $web['sys_groupid'];
+		}
+		/* get the name of the client */
+		$tmp = $app->db->queryOneRecord("SELECT name FROM sys_group WHERE groupid = " . $client_group_id);
+		$clientName = $tmp['name'];
+		if ($clientName == "") $clientName = 'default';
+		$clientName = convertClientName($clientName);
+		return $clientName;
+	
 	}
 	
 }

--
Gitblit v1.9.1